==> haskell-unixutils-1.54.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Unixutils
version: 1.54.1
id: Unixutils-1.54.1-AQ0ALCxTYxpERS8X7JpQWy
key: Unixutils-1.54.1-AQ0ALCxTYxpERS8X7JpQWy
license: BSD3
maintainer: jeremy@n-heptane.com
homepage: https://github.com/seereason/haskell-unixutils.git
synopsis: A crude interface between Haskell and Unix-like operating systems
description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.
category: System
author: Jeremy Shaw, David Fox
exposed: True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.KillByCwd System.Unix.Misc
    System.Unix.Mount System.Unix.SpecialDevice System.Unix.Files
abi: ff28f81bd678ce98a68817538b2f4f4d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/Unixutils-1.54.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/Unixutils-1.54.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/Unixutils-1.54.1
hs-libraries: HSUnixutils-1.54.1-AQ0ALCxTYxpERS8X7JpQWy
extra-libraries:
    crypt
depends:
    base-4.9.0.0 bytestring-0.10.8.1 directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN filepath-1.4.1.0
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM process-1.4.2.0
    process-extras-0.7.1-7TqC8vhOIIK2vBrs5N6oBr
    pureMD5-2.1.3-ZHHRnHF62x4STJ17kouoo
    regex-tdfa-1.2.2-LZ7BXF6FmWOD2v5FByhfgx unix-2.7.2.0
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html: /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unixutils-1.54.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Unixutils
version: 1.54.1
id: Unixutils-1.54.1-FMsKF5hkv0t10rCNIAgAKb
key: Unixutils-1.54.1-FMsKF5hkv0t10rCNIAgAKb
license: BSD3
maintainer: jeremy@n-heptane.com
homepage: https://github.com/seereason/haskell-unixutils.git
synopsis: A crude interface between Haskell and Unix-like operating systems
description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.
category: System
author: Jeremy Shaw, David Fox
exposed: True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.KillByCwd System.Unix.Misc
    System.Unix.Mount System.Unix.SpecialDevice System.Unix.Files
abi: f9067409d245a4afa49ef4456cbfa215
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/Unixutils-1.54.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/Unixutils-1.54.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/Unixutils-1.54.1
hs-libraries: HSUnixutils-1.54.1-FMsKF5hkv0t10rCNIAgAKb
extra-libraries:
    crypt
depends:
    base-4.9.0.0 bytestring-0.10.8.1 directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN filepath-1.4.1.0
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM process-1.4.2.0
    process-extras-0.7.1-CNpNu2J5fdcE1muVBFrX0v
    pureMD5-2.1.3-ZHHRnHF62x4STJ17kouoo
    regex-tdfa-1.2.2-LZ7BXF6FmWOD2v5FByhfgx unix-2.7.2.0
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html: /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
